@@ -4,6 +4,12 @@ const tbdTemplate = `--- !tapi-tbd
 tbd-version:          4
 targets:              [ {{ StringsJoin .Targets ", " }} ]
 install-name:         '{{.Path}}'
+{{ if .CurrentVersion }}current-version:      {{.CurrentVersion}}
+{{ end -}}
+{{ if .Umbrella }}parent-umbrella:
+  - targets:          [ {{ StringsJoin .Targets ", " }} ]
+    umbrella:         {{ .Umbrella }}
+{{ end -}}
 {{ if .ReExports }}reexported-libraries:
   - targets:          [ {{ StringsJoin .Targets ", " }} ]
     libraries:        [ '{{ StringsJoin .ReExports "', '" }}' ]
@@ -11,11 +17,10 @@ install-name:         '{{.Path}}'
 exports:
   - targets:          [ {{ StringsJoin .Targets ", " }} ]
     symbols:          [ {{ StringsJoin .Symbols ",\n                       " }} ]
-{{- if .ObjcClasses }}    
+{{- if .ObjcClasses }}
     objc-classes:    [ {{ StringsJoin .ObjcClasses ",\n                       " }} ]
 {{- end }}
-{{- if .ObjcIvars }}    
+{{- if .ObjcIvars }}
     objc-ivars:      [ {{ StringsJoin .ObjcIvars ",\n                       " }} ]
 {{- end }}
-...
 `
